# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetCalendarEventReq(object):
    calendar_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 日历ID, 示例值："feishu.cn_xxxxxxxxxx@group.calendar.feishu.cn"
    event_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 日程ID, 示例值："xxxxxxxxx_0"


@attr.s
class GetCalendarEventRespEventSchema(object):
    ui_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # UI名称。取值范围如下： \,ForwardIcon: 日程转发按钮 \,MeetingChatIcon: 会议群聊按钮 \,MeetingMinutesIcon: 会议纪要按钮 \,MeetingVideo: 视频会议区域 \,RSVP: 接受/拒绝/待定区域 \,Attendee: 参与者区域 \,OrganizerOrCreator: 组织者/创建者区域
    ui_status: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # UI项自定义状态。目前只支持hide, 可选值有: `hide`：隐藏显示, `readonly`：只读, `editable`：可编辑, `unknown`：未知UI项自定义状态，仅用于读取时兼容
    app_link: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 按钮点击后跳转的链接, 最大长度：`2000` 字符


@attr.s
class GetCalendarEventRespEventReminder(object):
    minutes: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 日程提醒时间的偏移量，正数时表示在日程开始前X分钟提醒，负数时表示在日程开始后X分钟提醒,新建或更新日程时传入该字段，仅对当前身份生效, 取值范围：`-20160` ～ `20160`


@attr.s
class GetCalendarEventRespEventLocationLongitude(object):
    pass


@attr.s
class GetCalendarEventRespEventLocationLatitude(object):
    pass


@attr.s
class GetCalendarEventRespEventLocation(object):
    name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 地点名称, 长度范围：`1` ～ `512` 字符
    address: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 地点地址, 长度范围：`1` ～ `255` 字符
    latitude: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 地点坐标纬度信息，对于国内的地点，采用GCJ-02标准，海外地点采用WGS84标准
    longitude: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 地点坐标经度信息，对于国内的地点，采用GCJ-02标准，海外地点采用WGS84标准


@attr.s
class GetCalendarEventRespEventVchat(object):
    vc_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 视频会议类型, 可选值有: `vc`：飞书视频会议，取该类型时，其他字段无效。, `third_party`：第三方链接视频会议，取该类型时，icon_type、description、meeting_url字段生效。, `no_meeting`：无视频会议，取该类型时，其他字段无效。, `lark_live`：Lark直播，内部类型，只读。, `unknown`：未知类型，做兼容使用，只读。
    icon_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 第三方视频会议icon类型；可以为空，为空展示默认icon。, 可选值有: `vc`：飞书视频会议icon, `live`：直播视频会议icon, `default`：默认icon
    description: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 第三方视频会议文案，可以为空，为空展示默认文案, 长度范围：`0` ～ `500` 字符
    meeting_url: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 视频会议URL, 长度范围：`1` ～ `2000` 字符


@attr.s
class GetCalendarEventRespEventEndTime(object):
    date: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 仅全天日程使用该字段，如2018-09-01。需满足 RFC3339 格式。不能与 timestamp 同时指定
    timestamp: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 秒级时间戳，如1602504000(表示2020/10/12 20:0:00 +8时区)
    timezone: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 时区名称，使用IANA Time Zone Database标准，如Asia/Shanghai；全天日程时区固定为UTC，非全天日程时区默认为Asia/Shanghai


@attr.s
class GetCalendarEventRespEventStartTime(object):
    date: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 仅全天日程使用该字段，如2018-09-01。需满足 RFC3339 格式。不能与 timestamp 同时指定
    timestamp: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 秒级时间戳，如1602504000(表示2020/10/12 20:0:00 +8时区)
    timezone: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 时区名称，使用IANA Time Zone Database标准，如Asia/Shanghai；全天日程时区固定为UTC，非全天日程时区默认为Asia/Shanghai


@attr.s
class GetCalendarEventRespEvent(object):
    event_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 日程ID
    summary: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 日程标题, 最大长度：`1000` 字符
    description: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 日程描述, 最大长度：`8192` 字符
    start_time: GetCalendarEventRespEventStartTime = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 日程开始时间
    end_time: GetCalendarEventRespEventEndTime = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 日程结束时间
    vchat: GetCalendarEventRespEventVchat = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 视频会议信息，仅当日程至少有一位attendee时生效
    visibility: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 日程公开范围，新建日程默认为Default；仅新建日程时对所有参与人生效，之后修改该属性仅对当前身份生效, 可选值有: `default`：默认权限，跟随日历权限，默认仅向他人显示是否“忙碌”, `public`：公开，显示日程详情, `private`：私密，仅自己可见详情
    attendee_ability: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 参与人权限, 可选值有: `none`：无法编辑日程、无法邀请其它参与人、无法查看参与人列表, `can_see_others`：无法编辑日程、无法邀请其它参与人、可以查看参与人列表, `can_invite_others`：无法编辑日程、可以邀请其它参与人、可以查看参与人列表, `can_modify_event`：可以编辑日程、可以邀请其它参与人、可以查看参与人列表
    free_busy_status: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 日程占用的忙闲状态，新建日程默认为Busy；仅新建日程时对所有参与人生效，之后修改该属性仅对当前身份生效, 可选值有: `busy`：忙碌, `free`：空闲
    location: GetCalendarEventRespEventLocation = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 日程地点
    color: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 日程颜色，颜色RGB值的int32表示。仅对当前身份生效；客户端展示时会映射到色板上最接近的一种颜色；值为0或-1时默认跟随日历颜色。
    reminders: typing.List[GetCalendarEventRespEventReminder] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 日程提醒列表
    recurrence: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 重复日程的重复性规则；参考[rfc5545](https://datatracker.ietf.org/doc/html/rfc5545#section-3.3.10)；, 不支持COUNT和UNTIL同时出现；, 预定会议室重复日程长度不得超过两年。, 最大长度：`2000` 字符
    status: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 日程状态, 可选值有: `tentative`：未回应, `confirmed`：已确认, `cancelled`：日程已取消
    is_exception: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 日程是否是一个重复日程的例外日程
    recurring_event_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 例外日程的原重复日程的event_id
    schemas: typing.List[GetCalendarEventRespEventSchema] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 日程自定义信息


@attr.s
class GetCalendarEventResp(object):
    event: GetCalendarEventRespEvent = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 日程实体


def _gen_get_calendar_event_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetCalendarEventResp,
        scope="Calendar",
        api="GetCalendarEvent",
        method="GET",
        url="https://open.feishu.cn/open-apis/calendar/v4/calendars/:calendar_id/events/:event_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetApprovalInstanceListReq(object):
    approval_code: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批定义唯一标识
    start_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 审批实例创建时间区间（毫秒）
    end_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 审批实例创建时间区间（毫秒）
    offset: int = attr.ib(default=0, metadata={"req_type": "json"})  # 查询偏移量
    limit: int = attr.ib(default=0, metadata={"req_type": "json"})  # 查询限制量 注:不得大于100


@attr.s
class GetApprovalInstanceListResp(object):
    instance_code_list: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 审批实例 Code


def _gen_get_approval_instance_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetApprovalInstanceListResp,
        scope="Approval",
        api="GetApprovalInstanceList",
        method="POST",
        url="https://www.feishu.cn/approval/openapi/v2/instance/list",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class PrepareUploadDriveFileReq(object):
    file_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件名, 示例值："test.txt", 最大长度：`250` 字符
    parent_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 上传点类型, 示例值："explorer", 可选值有: `explorer`：云空间
    parent_node: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件夹的token, 示例值："fldcnaBcdEfghdis"
    size: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 文件大小, 示例值：1024, 最小值：`0`


@attr.s
class PrepareUploadDriveFileResp(object):
    upload_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 分片上传事务ID
    block_size: int = attr.ib(default=0, metadata={"req_type": "json"})  # 分片大小策略
    block_num: int = attr.ib(default=0, metadata={"req_type": "json"})  # 分片数量


def _gen_prepare_upload_drive_file_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=PrepareUploadDriveFileResp,
        scope="Drive",
        api="PrepareUploadDriveFile",
        method="POST",
        url="https://open.feishu.cn/open-apis/drive/v1/files/upload_prepare",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_application_is_user_admin import (
    IsApplicationUserAdminReq,
    IsApplicationUserAdminResp,
    _gen_is_application_user_admin_req,
)
from pylark.api_service_application_user_admin_scope_get import (
    GetApplicationUserAdminScopeReq,
    GetApplicationUserAdminScopeResp,
    _gen_get_application_user_admin_scope_req,
)
from pylark.api_service_application_app_visibility_get import (
    GetApplicationAppVisibilityReq,
    GetApplicationAppVisibilityResp,
    _gen_get_application_app_visibility_req,
)
from pylark.api_service_application_user_visible_app_get import (
    GetApplicationUserVisibleAppReq,
    GetApplicationUserVisibleAppResp,
    _gen_get_application_user_visible_app_req,
)
from pylark.api_service_application_app_list import (
    GetApplicationAppListReq,
    GetApplicationAppListResp,
    _gen_get_application_app_list_req,
)
from pylark.api_service_application_app_visibility_update import (
    UpdateApplicationAppVisibilityReq,
    UpdateApplicationAppVisibilityResp,
    _gen_update_application_app_visibility_req,
)
from pylark.api_service_application_app_admin_user_list import (
    GetApplicationAppAdminUserListReq,
    GetApplicationAppAdminUserListResp,
    _gen_get_application_app_admin_user_list_req,
)
from pylark.api_service_application_paid_scope_check_user import (
    CheckUserIsInApplicationPaidScopeReq,
    CheckUserIsInApplicationPaidScopeResp,
    _gen_check_user_is_in_application_paid_scope_req,
)
from pylark.api_service_application_order_list import (
    GetApplicationOrderListReq,
    GetApplicationOrderListResp,
    _gen_get_application_order_list_req,
)
from pylark.api_service_application_order_get import (
    GetApplicationOrderReq,
    GetApplicationOrderResp,
    _gen_get_application_order_req,
)
from pylark.api_service_application_usage_overview import (
    GetApplicationUsageOverviewReq,
    GetApplicationUsageOverviewResp,
    _gen_get_application_usage_overview_req,
)
from pylark.api_service_application_usage_trend import (
    GetApplicationUsageTrendReq,
    GetApplicationUsageTrendResp,
    _gen_get_application_usage_trend_req,
)
from pylark.api_service_application_usage_detail import (
    GetApplicationUsageDetailReq,
    GetApplicationUsageDetailResp,
    _gen_get_application_usage_detail_req,
)
from pylark.api_service_application_message_overview import (
    GetApplicationMessageOverviewReq,
    GetApplicationMessageOverviewResp,
    _gen_get_application_message_overview_req,
)
from pylark.api_service_application_message_trend import (
    GetApplicationMessageTrendReq,
    GetApplicationMessageTrendResp,
    _gen_get_application_message_trend_req,
)
from pylark.api_service_application_message_detail import (
    GetApplicationMessageDetailReq,
    GetApplicationMessageDetailResp,
    _gen_get_application_message_detail_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkApplicationService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def is_application_user_admin(
        self, request: IsApplicationUserAdminReq, options: typing.List[str] = None
    ) -> typing.Tuple[IsApplicationUserAdminResp, Response]:
        return self.cli.raw_request(
            _gen_is_application_user_admin_req(request, options)
        )

    def get_application_user_admin_scope(
        self, request: GetApplicationUserAdminScopeReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetApplicationUserAdminScopeResp, Response]:
        return self.cli.raw_request(
            _gen_get_application_user_admin_scope_req(request, options)
        )

    def get_application_app_visibility(
        self, request: GetApplicationAppVisibilityReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetApplicationAppVisibilityResp, Response]:
        return self.cli.raw_request(
            _gen_get_application_app_visibility_req(request, options)
        )

    def get_application_user_visible_app(
        self, request: GetApplicationUserVisibleAppReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetApplicationUserVisibleAppResp, Response]:
        return self.cli.raw_request(
            _gen_get_application_user_visible_app_req(request, options)
        )

    def get_application_app_list(
        self, request: GetApplicationAppListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetApplicationAppListResp, Response]:
        return self.cli.raw_request(_gen_get_application_app_list_req(request, options))

    def update_application_app_visibility(
        self,
        request: UpdateApplicationAppVisibilityReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[UpdateApplicationAppVisibilityResp, Response]:
        return self.cli.raw_request(
            _gen_update_application_app_visibility_req(request, options)
        )

    def get_application_app_admin_user_list(
        self,
        request: GetApplicationAppAdminUserListReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[GetApplicationAppAdminUserListResp, Response]:
        return self.cli.raw_request(
            _gen_get_application_app_admin_user_list_req(request, options)
        )

    def check_user_is_in_application_paid_scope(
        self,
        request: CheckUserIsInApplicationPaidScopeReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[CheckUserIsInApplicationPaidScopeResp, Response]:
        return self.cli.raw_request(
            _gen_check_user_is_in_application_paid_scope_req(request, options)
        )

    def get_application_order_list(
        self, request: GetApplicationOrderListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetApplicationOrderListResp, Response]:
        return self.cli.raw_request(
            _gen_get_application_order_list_req(request, options)
        )

    def get_application_order(
        self, request: GetApplicationOrderReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetApplicationOrderResp, Response]:
        return self.cli.raw_request(_gen_get_application_order_req(request, options))

    def get_application_usage_overview(
        self, request: GetApplicationUsageOverviewReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetApplicationUsageOverviewResp, Response]:
        return self.cli.raw_request(
            _gen_get_application_usage_overview_req(request, options)
        )

    def get_application_usage_trend(
        self, request: GetApplicationUsageTrendReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetApplicationUsageTrendResp, Response]:
        return self.cli.raw_request(
            _gen_get_application_usage_trend_req(request, options)
        )

    def get_application_usage_detail(
        self, request: GetApplicationUsageDetailReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetApplicationUsageDetailResp, Response]:
        return self.cli.raw_request(
            _gen_get_application_usage_detail_req(request, options)
        )

    def get_application_message_overview(
        self,
        request: GetApplicationMessageOverviewReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[GetApplicationMessageOverviewResp, Response]:
        return self.cli.raw_request(
            _gen_get_application_message_overview_req(request, options)
        )

    def get_application_message_trend(
        self, request: GetApplicationMessageTrendReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetApplicationMessageTrendResp, Response]:
        return self.cli.raw_request(
            _gen_get_application_message_trend_req(request, options)
        )

    def get_application_message_detail(
        self, request: GetApplicationMessageDetailReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetApplicationMessageDetailResp, Response]:
        return self.cli.raw_request(
            _gen_get_application_message_detail_req(request, options)
        )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateIdentityReqUserIDType(object):
    pass


@attr.s
class CreateIdentityReq(object):
    user_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 用户的唯一标识, 示例值: "ou_2eb5483cb377daa5054bc6f86e2089a5"
    user_id_type: CreateIdentityReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户ID类型, 示例值: "open_id", 可选值有: `open_id`：用户的open id, `union_id`：用户的union id, `user_id`：用户的user id, 默认值: `open_id`, 当值为 `user_id`，字段权限要求: 获取用户 userid
    identity_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # user identity name, 示例值: "张三"
    identity_code: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # user identity code, 示例值: "4xxxxxxxx"
    mobile: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # user mobile, 示例值: "13xxxxxxx"


@attr.s
class CreateIdentityResp(object):
    verify_uid: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户绑定实名身份的uid


def _gen_create_identity_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateIdentityResp,
        scope="HumanAuth",
        api="CreateIdentity",
        method="POST",
        url="https://open.feishu.cn/open-apis/human_authentication/v1/identities",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class FindSheetReqFindCondition(object):
    range_: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 查找范围, 示例值："0b**12!A1:H10"
    match_case: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否忽略大小写, 示例值：true
    match_entire_cell: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否匹配整个单元格, 示例值：false
    search_by_regex: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否为正则匹配, 示例值：false
    include_formulas: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否搜索公式内容, 示例值：false


@attr.s
class FindSheetReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 表格的 token, 示例值："shtcnmBA*****yGehy8"
    sheet_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 子表的 id, 示例值："0b**12"
    find_condition: FindSheetReqFindCondition = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 查找条件
    find: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 查找的字符串, 示例值："hello"


@attr.s
class FindSheetRespFindResult(object):
    matched_cells: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 符合查找条件的单元格数组，不包含公式，例如["A1", "A2"...]
    matched_formula_cells: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 符合查找条件的含有公式的单元格数组，例如["B3", "H7"...]
    rows_count: int = attr.ib(default=0, metadata={"req_type": "json"})  # 符合查找条件的总行数


@attr.s
class FindSheetResp(object):
    find_result: FindSheetRespFindResult = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 查找返回符合条件的信息


def _gen_find_sheet_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=FindSheetResp,
        scope="Drive",
        api="FindSheet",
        method="POST",
        url="https://open.feishu.cn/open-apis/sheets/v3/spreadsheets/:spreadsheet_token/sheets/:sheet_id/find",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateMailGroupMemberReqType(object):
    pass


@attr.s
class CreateMailGroupMemberReqDepartmentIDType(object):
    pass


@attr.s
class CreateMailGroupMemberReqUserIDType(object):
    pass


@attr.s
class CreateMailGroupMemberReq(object):
    user_id_type: CreateMailGroupMemberReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    department_id_type: CreateMailGroupMemberReqDepartmentIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 此次调用中使用的部门ID的类型, 示例值："open_department_id", 可选值有: `department_id`：以自定义department_id来标识部门, `open_department_id`：以open_department_id来标识部门
    mailgroup_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 邮件组ID或者邮件组地址, 示例值："xxxxxxxxxxxxxxx 或 test_mail_group@xxx.xx"
    email: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 成员邮箱地址（当成员类型是EXTERNAL_USER/MAIL_GROUP/OTHER_MEMBER时有值）, 示例值："test_memeber@xxx.xx"
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户内用户的唯一标识（当成员类型是USER时有值）, 示例值："xxxxxxxxxx"
    department_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户内部门的唯一标识（当成员类型是DEPARTMENT时有值）, 示例值："xxxxxxxxxx"
    type: CreateMailGroupMemberReqType = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 成员类型, 示例值："USER", 可选值有: `USER`：内部用户, `DEPARTMENT`：部门, `COMPANY`：全员, `EXTERNAL_USER`：外部用户, `MAIL_GROUP`：邮件组, `OTHER_MEMBER`：内部成员


@attr.s
class CreateMailGroupMemberRespType(object):
    pass


@attr.s
class CreateMailGroupMemberResp(object):
    member_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 邮件组内成员唯一标识
    email: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 成员邮箱地址（当成员类型是EXTERNAL_USER/MAIL_GROUP/OTHER_MEMBER时有值）
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户内用户的唯一标识（当成员类型是USER时有值）
    department_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户内部门的唯一标识（当成员类型是DEPARTMENT时有值）
    type: CreateMailGroupMemberRespType = attr.ib(
        factory=lambda: CreateMailGroupMemberRespType(), metadata={"req_type": "json"}
    )  # 成员类型, 可选值有: `USER`：内部用户, `DEPARTMENT`：部门, `COMPANY`：全员, `EXTERNAL_USER`：外部用户, `MAIL_GROUP`：邮件组, `OTHER_MEMBER`：内部成员


def _gen_create_mail_group_member_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateMailGroupMemberResp,
        scope="Mail",
        api="CreateMailGroupMember",
        method="POST",
        url="https://open.feishu.cn/open-apis/mail/v1/mailgroups/:mailgroup_id/members",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# coding: utf-8

from __future__ import absolute_import, division, print_function, unicode_literals

import inspect
from copy import deepcopy
from enum import Enum
from io import BytesIO
from typing import List, TypeVar, Type, Any

import attr

T = TypeVar("T")


def _to_file_like(image):
    if isinstance(image, bytes):
        return BytesIO(image)

    if isinstance(image, str):
        return open(image, "rb")

    return image


def _to_attr_dict(data):
    if isinstance(data, dict):
        return {k: _to_attr_dict(v) for k, v in data.items()}
    if isinstance(data, list):
        return [_to_attr_dict(v) for v in data]
    if attr.has(data):
        return attr.asdict(data)
    return data


def _to_json(cls):
    def _f(self):
        if not hasattr(self, "__dict__"):
            return self

        d = {}
        for k, v in self.__dict__.items():
            if hasattr(v, "json"):
                d[k] = v.json()
            elif isinstance(v, list):
                d[k] = [_f(i) for i in v]
            elif isinstance(v, dict):
                d[k] = {kk: _f(vv) for kk, vv in v.items()}
            elif isinstance(v, Enum):
                d[k] = v.value
            else:
                d[k] = v

        return d

    cls.json = _f
    return cls


def _make_dataclass_from_dict(t: Type[T], kwargs: Any) -> T:
    kwargs = deepcopy(kwargs)

    if inspect.isclass(t) and issubclass(t, Enum):
        return t(kwargs)

    if isinstance(kwargs, (int, str, bool)):
        return kwargs

    if t.__class__ == List.__class__ and isinstance(kwargs, list):
        return [_make_dataclass_from_dict(t.__args__[0], i) for i in kwargs]

    if not hasattr(t, "__attrs_attrs__"):
        return kwargs

    d = {}
    attr_field = attr.fields(t)
    for att in getattr(t, "__attrs_attrs__", []):
        att_name = att.name
        json_name = getattr(attr_field, att.name).metadata.get("json") or att_name
        att_default = att.default
        att_value = kwargs.get(json_name)
        if att_value:
            d[att_name] = _make_dataclass_from_dict(att.type, att_value)
            del kwargs[json_name]
        elif att_default is attr.NOTHING:
            d[att_name] = None

    return t(**d)



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class ReplyRawMessageReqMsgType(object):
    pass


@attr.s
class ReplyRawMessageReq(object):
    message_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 待回复的消息的ID, 示例值："om_dc13264520392913993dd051dba21dcf"
    content: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 消息内容 json 格式，格式说明参考: [发送消息content说明](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/im-v1/message/create_json), 示例值："{\"text\":\"<at user_id=\"ou_155184d1e73cbfb8973e5a9e698e74f2\">Tom</at> test content\"}"
    msg_type: ReplyRawMessageReqMsgType = attr.ib(
        factory=lambda: ReplyRawMessageReqMsgType(), metadata={"req_type": "json"}
    )  # 消息类型，包括：text、post、image、file、audio、media、sticker、interactive、share_card、share_user, 示例值："text"


@attr.s
class ReplyRawMessageRespMentionIDType(object):
    pass


@attr.s
class ReplyRawMessageRespMention(object):
    key: str = attr.ib(default="", metadata={"req_type": "json"})  # mention key
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户open id
    id_type: ReplyRawMessageRespMentionIDType = attr.ib(
        factory=lambda: ReplyRawMessageRespMentionIDType(),
        metadata={"req_type": "json"},
    )  # id 可以是open_id，user_id或者union_id
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 被at用户的姓名


@attr.s
class ReplyRawMessageRespBody(object):
    content: str = attr.ib(default="", metadata={"req_type": "json"})  # 消息jsonContent


@attr.s
class ReplyRawMessageRespSenderIDType(object):
    pass


@attr.s
class ReplyRawMessageRespSender(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 该字段标识发送者的id
    id_type: ReplyRawMessageRespSenderIDType = attr.ib(
        factory=lambda: ReplyRawMessageRespSenderIDType(), metadata={"req_type": "json"}
    )  # 该字段标识发送者的id类型
    sender_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 该字段标识发送者的类型


@attr.s
class ReplyRawMessageRespMsgType(object):
    pass


@attr.s
class ReplyRawMessageResp(object):
    message_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 消息id open_message_id
    root_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 根消息id open_message_id
    parent_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 父消息的id open_message_id
    msg_type: ReplyRawMessageRespMsgType = attr.ib(
        factory=lambda: ReplyRawMessageRespMsgType(), metadata={"req_type": "json"}
    )  # 消息类型 text post card image等等
    create_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 消息生成的时间戳(毫秒)
    update_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 消息更新的时间戳
    deleted: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 消息是否被撤回
    updated: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 消息是否被更新
    chat_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 所属的群
    sender: ReplyRawMessageRespSender = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 发送者，可以是用户或应用
    body: ReplyRawMessageRespBody = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 消息内容，json结构，格式说明参考： [消息content说明](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/im-v1/message/events/message_content)
    mentions: typing.List[ReplyRawMessageRespMention] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 被艾特的人或应用的id
    upper_message_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 上一层级的消息id open_message_id


def _gen_reply_raw_message_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=ReplyRawMessageResp,
        scope="Message",
        api="ReplyRawMessage",
        method="POST",
        url="https://open.feishu.cn/open-apis/im/v1/messages/:message_id/reply",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_ai_recognize_basic_image import (
    RecognizeBasicImageReq,
    RecognizeBasicImageResp,
    _gen_recognize_basic_image_req,
)
from pylark.api_service_ai_recognize_speech_stream import (
    RecognizeSpeechStreamReq,
    RecognizeSpeechStreamResp,
    _gen_recognize_speech_stream_req,
)
from pylark.api_service_ai_recognize_speech_file import (
    RecognizeSpeechFileReq,
    RecognizeSpeechFileResp,
    _gen_recognize_speech_file_req,
)
from pylark.api_service_ai_translate_text import (
    TranslateTextReq,
    TranslateTextResp,
    _gen_translate_text_req,
)
from pylark.api_service_ai_detect_text_language import (
    DetectTextLanguageReq,
    DetectTextLanguageResp,
    _gen_detect_text_language_req,
)
from pylark.api_service_ai_detect_face_attributes import (
    DetectFaceAttributesReq,
    DetectFaceAttributesResp,
    _gen_detect_face_attributes_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkAIService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def recognize_basic_image(
        self, request: RecognizeBasicImageReq, options: typing.List[str] = None
    ) -> typing.Tuple[RecognizeBasicImageResp, Response]:
        return self.cli.raw_request(_gen_recognize_basic_image_req(request, options))

    def recognize_speech_stream(
        self, request: RecognizeSpeechStreamReq, options: typing.List[str] = None
    ) -> typing.Tuple[RecognizeSpeechStreamResp, Response]:
        return self.cli.raw_request(_gen_recognize_speech_stream_req(request, options))

    def recognize_speech_file(
        self, request: RecognizeSpeechFileReq, options: typing.List[str] = None
    ) -> typing.Tuple[RecognizeSpeechFileResp, Response]:
        return self.cli.raw_request(_gen_recognize_speech_file_req(request, options))

    def translate_text(
        self, request: TranslateTextReq, options: typing.List[str] = None
    ) -> typing.Tuple[TranslateTextResp, Response]:
        return self.cli.raw_request(_gen_translate_text_req(request, options))

    def detect_text_language(
        self, request: DetectTextLanguageReq, options: typing.List[str] = None
    ) -> typing.Tuple[DetectTextLanguageResp, Response]:
        return self.cli.raw_request(_gen_detect_text_language_req(request, options))

    def detect_face_attributes(
        self, request: DetectFaceAttributesReq, options: typing.List[str] = None
    ) -> typing.Tuple[DetectFaceAttributesResp, Response]:
        return self.cli.raw_request(_gen_detect_face_attributes_req(request, options))



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class OpenCalenderViewReq(object):
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 视图类型，枚举值包括：<br> `day`：日视图 <br>`three_day`：三日视图，仅移动端支持<br> `week`：周视图，仅PC端支持 <br>  `month`：月视图<br> `meeting`：会议室视图，仅PC端支持 <br> `list`：列表视图，仅移动端支持
    date: str = attr.ib(default="", metadata={"req_type": "json"})  # 日期，{unixTime}格式


@attr.s
class OpenCalenderViewResp(object):
    pass


def _gen_open_calender_view_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=OpenCalenderViewResp,
        scope="AppLink",
        api="OpenCalenderView",
        method="",
        url="https://applink.feishu.cn/client/calendar/view",
        body=request,
        method_option=_new_method_option(options),
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetApprovalInstanceReq(object):
    instance_code: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例 Code
    locale: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # zh-CN - 中文<br>en-US - 英文<br>ja-JP - 日文
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 发起审批用户,平台级审批时使用
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 发起审批用户 open id


@attr.s
class GetApprovalInstanceRespTimelineExt(object):
    user_id_list: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # **type类型** - **user_id_list 含义**<br>TRANSFER - 被转交人 <br>ADD_APPROVER_BEFORE  -  被加签人<br>ADD_APPROVER -   被加签人<br>ADD_APPROVER_AFTER -   被加签人 <br>DELETE_APPROVER  - 被减签人
    open_id_list: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # user_id_list 对应的 open id
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # **type类型** - **user_id 含义**<br>CC - 抄送人
    open_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # user_id 对应的 open_id


@attr.s
class GetApprovalInstanceRespTimelineCcUser(object):
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 抄送人 user id
    cc_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例内抄送唯一标识
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 抄送人 open id


@attr.s
class GetApprovalInstanceRespTimeline(object):
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 动态类型，不同类型 ext 内的 user_id_list 含义不一样<br>START - 审批开始<br>PASS - 通过<br>REJECT  - 拒绝<br>AUTO_PASS -  自动通过<br>AUTO_REJECT - 自动拒绝<br>REMOVE_REPEAT - 去重<br>TRANSFER - 转交 <br>ADD_APPROVER_BEFORE  - 前加签<br>ADD_APPROVER -  并加签<br>ADD_APPROVER_AFTER -  后加签 <br>DELETE_APPROVER  - 减签<br>ROLLBACK_SELECTED -  指定回退<br>ROLLBACK - 全部回退<br>CANCEL -  撤回<br>DELETE - 删除<br>CC - 抄送
    create_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 发生时间
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 动态产生用户
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 动态产生用户 open id
    user_id_list: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 被抄送人列表
    open_id_list: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 被抄送人列表
    task_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 产生动态关联的task_id
    comment: str = attr.ib(default="", metadata={"req_type": "json"})  # 理由
    cc_user_list: typing.List[GetApprovalInstanceRespTimelineCcUser] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 抄送人列表
    ext: GetApprovalInstanceRespTimelineExt = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 动态其他信息，目前包括 user_id_list, user_id


@attr.s
class GetApprovalInstanceRespComment(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # comment id
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 发表评论用户
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 发表评论用户 open id
    comment: str = attr.ib(default="", metadata={"req_type": "json"})  # 评论内容
    create_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 评论时间


@attr.s
class GetApprovalInstanceRespTask(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # task id
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批人<br>自动通过、自动拒绝 task user_id 为空
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批人 open id
    status: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 任务状态<br>PENDING - 审批中<br>APPROVED - 同意<br>REJECTED  - 拒绝<br>TRANSFERRED - 已转交<br>DONE -  完成
    node_id: str = attr.ib(default="", metadata={"req_type": "json"})  # task 所属节点 id
    node_name: str = attr.ib(default="", metadata={"req_type": "json"})  # task 所属节点名称
    custom_node_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # task 所属节点自定义 id, 如果没设置自定义 id, 则不返回该字段
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批方式<br>AND -会签<br>OR - 或签<br>AUTO_PASS -自动通过<br>AUTO_REJECT - 自动拒绝<br>SEQUENTIAL - 按顺序
    start_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # task 开始时间
    end_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # task 完成时间, 未完成为 0


@attr.s
class GetApprovalInstanceRespForm(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 控件 id
    custom_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 控件自定义 id，如果没有设置自定义 id，则不返回该字段
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 控件名称
    type: str = attr.ib(default="", metadata={"req_type": "json"})  # 控件类型
    value: str = attr.ib(default="", metadata={"req_type": "json"})  # 控件值，不同类型格式不一样


@attr.s
class GetApprovalInstanceResp(object):
    approval_code: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批定义 Code
    approval_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批名称
    start_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 审批创建时间
    end_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 审批完成时间，未完成为 0
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 发起审批用户
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 发起审批用户 open id
    serial_number: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批单编号
    department_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 发起审批用户所在部门
    status: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批实例状态<br>PENDING    - 审批中<br>APPROVED - 通过<br>REJECTED  - 拒绝<br>CANCELED -  撤回<br>DELETED    -  删除
    uuid: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户的唯一标识id
    form: GetApprovalInstanceRespForm = attr.ib(
        factory=lambda: GetApprovalInstanceRespForm(), metadata={"req_type": "json"}
    )  # json数组，**控件值**
    task_list: typing.List[GetApprovalInstanceRespTask] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 审批任务列表
    comment_list: typing.List[GetApprovalInstanceRespComment] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 评论列表
    timeline: typing.List[GetApprovalInstanceRespTimeline] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 审批动态


def _gen_get_approval_instance_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetApprovalInstanceResp,
        scope="Approval",
        api="GetApprovalInstance",
        method="POST",
        url="https://www.feishu.cn/approval/openapi/v2/instance/get",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateHireApplicationReq(object):
    talent_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 人才ID, 示例值："12312312312"
    job_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 职位ID, 示例值："12312312312"


@attr.s
class CreateHireApplicationResp(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 投递ID


def _gen_create_hire_application_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateHireApplicationResp,
        scope="Hire",
        api="CreateHireApplication",
        method="POST",
        url="https://open.feishu.cn/open-apis/hire/v1/applications",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetMessageReq(object):
    message_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 待获取消息内容的消息的ID, 示例值："om_dc13264520392913993dd051dba21dcf"


@attr.s
class GetMessageRespItemMentionIDType(object):
    pass


@attr.s
class GetMessageRespItemMention(object):
    key: str = attr.ib(default="", metadata={"req_type": "json"})  # mention key
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户open id
    id_type: GetMessageRespItemMentionIDType = attr.ib(
        factory=lambda: GetMessageRespItemMentionIDType(), metadata={"req_type": "json"}
    )  # id 可以是open_id，user_id或者union_id
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 被at用户的姓名


@attr.s
class GetMessageRespItemBody(object):
    content: str = attr.ib(default="", metadata={"req_type": "json"})  # 消息jsonContent


@attr.s
class GetMessageRespItemSenderIDType(object):
    pass


@attr.s
class GetMessageRespItemSender(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 该字段标识发送者的id
    id_type: GetMessageRespItemSenderIDType = attr.ib(
        factory=lambda: GetMessageRespItemSenderIDType(), metadata={"req_type": "json"}
    )  # 该字段标识发送者的id类型
    sender_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 该字段标识发送者的类型


@attr.s
class GetMessageRespItemMsgType(object):
    pass


@attr.s
class GetMessageRespItem(object):
    message_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 消息id open_message_id
    root_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 根消息id open_message_id
    parent_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 父消息的id open_message_id
    msg_type: GetMessageRespItemMsgType = attr.ib(
        factory=lambda: GetMessageRespItemMsgType(), metadata={"req_type": "json"}
    )  # 消息类型 text post card image等等
    create_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 消息生成的时间戳(毫秒)
    update_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 消息更新的时间戳
    deleted: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 消息是否被撤回
    updated: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 消息是否被更新
    chat_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 所属的群
    sender: GetMessageRespItemSender = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 发送者，可以是用户或应用
    body: GetMessageRespItemBody = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 消息内容，json结构，格式说明参考： [消息content说明](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/im-v1/message/events/message_content)
    mentions: typing.List[GetMessageRespItemMention] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 被艾特的人或应用的id
    upper_message_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 上一层级的消息id open_message_id


@attr.s
class GetMessageResp(object):
    items: typing.List[GetMessageRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # -


def _gen_get_message_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetMessageResp,
        scope="Message",
        api="GetMessage",
        method="GET",
        url="https://open.feishu.cn/open-apis/im/v1/messages/:message_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class StartHelpdeskServiceReq(object):
    human_service: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否直接进入人工(若appointed_agents填写了，该值为必填), 示例值：false
    appointed_agents: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 客服 open ids (获取方式参考[获取单个用户信息](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/reference/contact-v3/user/get))，human_service需要为true
    open_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户 open id,(获取方式参考[获取单个用户信息](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/reference/contact-v3/user/get)), 示例值："ou_7dab8a3d3cdcc9da365777c7ad535d62"
    customized_info: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 工单来源自定义信息，长度限制1024字符，如设置，[获取工单详情](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/helpdesk-v1/ticket/get)会返回此信息, 示例值："test customized info"


@attr.s
class StartHelpdeskServiceResp(object):
    chat_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 客服群open ID
    ticket_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 工单ID


def _gen_start_helpdesk_service_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=StartHelpdeskServiceResp,
        scope="Helpdesk",
        api="StartHelpdeskService",
        method="POST",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/start_service",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateChatReqMembershipApproval(object):
    pass


@attr.s
class UpdateChatReqLeaveMessageVisibility(object):
    pass


@attr.s
class UpdateChatReqJoinMessageVisibility(object):
    pass


@attr.s
class UpdateChatReqEditPermission(object):
    pass


@attr.s
class UpdateChatReqAtAllPermission(object):
    pass


@attr.s
class UpdateChatReqShareCardPermission(object):
    pass


@attr.s
class UpdateChatReqAddMemberPermission(object):
    pass


@attr.s
class UpdateChatReqI18nNames(object):
    zh_cn: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名, 示例值："群聊"
    en_us: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 英文名, 示例值："group chat"
    ja_jp: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 日文名, 示例值："グループチャット"


@attr.s
class UpdateChatReqUserIDType(object):
    pass


@attr.s
class UpdateChatReq(object):
    user_id_type: UpdateChatReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    chat_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 群 ID, 示例值："oc_a0553eda9014c201e6969b478895c230"
    avatar: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 群头像对应的 Image Key，可通过[上传图片](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/reference/im-v1/image/create)获取（注意：上传图片的 [image_type] 需要指定为 [avatar]）, 示例值："default-avatar_44ae0ca3-e140-494b-956f-78091e348435"
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 群名称, 示例值："测试群名称"
    description: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 群描述, 示例值："测试群描述"
    i18n_names: UpdateChatReqI18nNames = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 群国际化名称
    add_member_permission: UpdateChatReqAddMemberPermission = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 加 user/bot 入群权限(all_members/only_owner), 示例值："all_members"
    share_card_permission: UpdateChatReqShareCardPermission = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 群分享权限(allowed/not_allowed), 示例值："allowed"
    at_all_permission: UpdateChatReqAtAllPermission = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # at 所有人权限(all_members/only_owner), 示例值："all_members"
    edit_permission: UpdateChatReqEditPermission = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 群编辑权限(all_members/only_owner), 示例值："all_members"
    owner_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 新群主 ID, 示例值："4d7a3c6g"
    join_message_visibility: UpdateChatReqJoinMessageVisibility = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 入群消息可见性(only_owner/all_members/not_anyone), 示例值："only_owner"
    leave_message_visibility: UpdateChatReqLeaveMessageVisibility = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 出群消息可见性(only_owner/all_members/not_anyone), 示例值："only_owner"
    membership_approval: UpdateChatReqMembershipApproval = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 加群审批(no_approval_required/approval_required), 示例值："no_approval_required"


@attr.s
class UpdateChatResp(object):
    pass


def _gen_update_chat_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateChatResp,
        scope="Chat",
        api="UpdateChat",
        method="PUT",
        url="https://open.feishu.cn/open-apis/im/v1/chats/:chat_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class OpenChatReq(object):
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户 openId
    open_chat_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 会话ID，包括单聊会话和群聊会话。示例：oc_41e7bdf4877cfc316136f4ccf6c32613


@attr.s
class OpenChatResp(object):
    pass


def _gen_open_chat_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=OpenChatResp,
        scope="AppLink",
        api="OpenChat",
        method="",
        url="https://applink.feishu.cn/client/chat/open",
        body=request,
        method_option=_new_method_option(options),
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteTaskCollaboratorReq(object):
    task_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 任务 ID, 示例值："83912691-2e43-47fc-94a4-d512e03984fa"
    collaborator_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 任务协作者 ID（Open ID）, 示例值："ou_99e1a581b36ecc4862cbfbce123f346a"


@attr.s
class DeleteTaskCollaboratorResp(object):
    pass


def _gen_delete_task_collaborator_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteTaskCollaboratorResp,
        scope="Task",
        api="DeleteTaskCollaborator",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/task/v1/tasks/:task_id/collaborators/:collaborator_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetBotInfoReq(object):
    pass


@attr.s
class GetBotInfoResp(object):
    activate_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # app 当前状态。,0: 初始化，租户待安装,1: 租户停用,2: 租户启用,3: 安装后待启用,4: 升级待启用,5: license过期停用,6: Lark套餐到期或降级停用
    app_name: str = attr.ib(default="", metadata={"req_type": "json"})  # app 名称
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # app 图像地址
    ip_white_list: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # app 的 IP 白名单地址
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 机器人的open_id


def _gen_get_bot_info_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetBotInfoResp,
        scope="Bot",
        api="GetBotInfo",
        method="GET",
        url="https://open.feishu.cn/open-apis/bot/v3/info",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetMeetingRoomBuildingListReq(object):
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 请求期望返回的建筑物数量，不足则返回全部，该值默认为 10，最大为 100
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 用于标记当前请求的分页标记，将返回以当前分页标记开始，往后 page_size 个元素
    order_by: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 提供用于对名称进行升序/降序排序的方式查询，可选项有："name-asc,name-desc"，传入其他字符串不做处理，默认无序
    fields: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 用于指定返回的字段名，每个字段名之间用逗号 "," 分隔，如：“id,name”，"*" 表示返回全部字段，可选字段有："id,name,description,floors"，默认返回所有字段


@attr.s
class GetMeetingRoomBuildingListRespBuildings(object):
    building_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 建筑物 ID
    description: str = attr.ib(default="", metadata={"req_type": "json"})  # 建筑物的相关描述
    floors: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 属于当前建筑物的所有楼层列表
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 建筑物名称


@attr.s
class GetMeetingRoomBuildingListResp(object):
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，存在下一页时返回
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 存在下一页时，该值为 true，否则为 false
    buildings: GetMeetingRoomBuildingListRespBuildings = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 建筑列表


def _gen_get_meeting_room_building_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetMeetingRoomBuildingListResp,
        scope="MeetingRoom",
        api="GetMeetingRoomBuildingList",
        method="GET",
        url="https://open.feishu.cn/open-apis/meeting_room/building/list",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateHelpdeskFAQReqFAQ(object):
    category_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 知识库分类ID, 示例值："6836004780707807251"
    question: str = attr.ib(default="", metadata={"req_type": "json"})  # 问题, 示例值："问题"
    answer: str = attr.ib(default="", metadata={"req_type": "json"})  # 答案, 示例值："答案"
    answer_richtext: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 富文本答案和答案必须有一个必填。Json Array格式，富文本结构请见[了解更多: 富文本](https://open.feishu.cn/document/ukTMukTMukTM/uITM0YjLyEDN24iMxQjN), 示例值："[{,                        "content": "这只是一个测试，医保问题",,                        "type": "text",                    }]"
    tags: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 关联词


@attr.s
class CreateHelpdeskFAQReq(object):
    faq: CreateHelpdeskFAQReqFAQ = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 知识库详情


@attr.s
class CreateHelpdeskFAQRespFAQCreateUser(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像url
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户名


@attr.s
class CreateHelpdeskFAQRespFAQUpdateUser(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像url
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户名


@attr.s
class CreateHelpdeskFAQRespFAQCategorie(object):
    category_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 知识库分类ID
    id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 知识库分类ID，（旧版，请使用category_id）
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名称
    parent_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 父知识库分类ID
    helpdesk_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 服务台ID
    language: str = attr.ib(default="", metadata={"req_type": "json"})  # 语言


@attr.s
class CreateHelpdeskFAQRespFAQ(object):
    faq_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 知识库ID
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 知识库旧版ID，请使用faq_id
    helpdesk_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 服务台ID
    question: str = attr.ib(default="", metadata={"req_type": "json"})  # 问题
    answer: str = attr.ib(default="", metadata={"req_type": "json"})  # 答案
    answer_richtext: str = attr.ib(default="", metadata={"req_type": "json"})  # 富文本答案
    create_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 创建时间
    update_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 修改时间
    categories: typing.List[CreateHelpdeskFAQRespFAQCategorie] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 分类
    tags: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 关联词列表
    expire_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 失效时间
    update_user: CreateHelpdeskFAQRespFAQUpdateUser = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 更新用户
    create_user: CreateHelpdeskFAQRespFAQCreateUser = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 创建用户


@attr.s
class CreateHelpdeskFAQResp(object):
    faq: CreateHelpdeskFAQRespFAQ = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 知识库详情


def _gen_create_helpdesk_faq_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateHelpdeskFAQResp,
        scope="Helpdesk",
        api="CreateHelpdeskFAQ",
        method="POST",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/faqs",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetApplicationUsageTrendReqFilter(object):
    key: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 过滤字段，支持`department_id`
    op: str = attr.ib(default="", metadata={"req_type": "json"})  # 过滤操作，支持`in`、`=`
    value: str = attr.ib(default="", metadata={"req_type": "json"})  # 过滤字段值，多个使用英文逗号分隔


@attr.s
class GetApplicationUsageTrendReq(object):
    app_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 目标应用的 ID，支持自建应用
    ability: str = attr.ib(default="", metadata={"req_type": "json"})  # 应用能力，mp：小程序
    time_start: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 起始时间戳（秒），时间跨度最长支持180天
    time_end: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 截止时间戳（秒），时间跨度最长支持180天
    time_interval: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 步长（秒），最小步长为60秒，需满足(${time_end} - ${time_start}) / ${time_interval} <= 2*24*60
    filters: typing.List[GetApplicationUsageTrendReqFilter] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 过滤条件


@attr.s
class GetApplicationUsageTrendRespItemTrend(object):
    timestamp: int = attr.ib(default=0, metadata={"req_type": "json"})  # 时间戳
    pv: int = attr.ib(default=0, metadata={"req_type": "json"})  # 应用使用pv
    uv: int = attr.ib(default=0, metadata={"req_type": "json"})  # 应用使用uv


@attr.s
class GetApplicationUsageTrendRespItem(object):
    trends: typing.List[GetApplicationUsageTrendRespItemTrend] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 趋势数据


@attr.s
class GetApplicationUsageTrendResp(object):
    item: GetApplicationUsageTrendRespItem = attr.ib(
        factory=lambda: GetApplicationUsageTrendRespItem(),
        metadata={"req_type": "json"},
    )  # 返回项


def _gen_get_application_usage_trend_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetApplicationUsageTrendResp,
        scope="Application",
        api="GetApplicationUsageTrend",
        method="POST",
        url="https://open.feishu.cn/open-apis/application/v1/app_usage_trend",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class TransferDriveMemberPermissionReqOwner(object):
    member_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户类型，可选 **email、openid、userid**
    member_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户类型下的值


@attr.s
class TransferDriveMemberPermissionReq(object):
    token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件的 token，获取方式见 [对接前说明](https://open.feishu.cn/document/ukTMukTMukTM/uczNzUjL3czM14yN3MTN)的第 4 项
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文档类型  "doc"  or  "sheet" or "bitable"  or "file"
    owner: TransferDriveMemberPermissionReqOwner = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 要转移到的新的文档所有者
    remove_old_owner: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # true 为转移后删除旧 owner 的权限，默认为false
    cancel_notify: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # true为不通知新owner，默认为false


@attr.s
class TransferDriveMemberPermissionRespOwner(object):
    member_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户类型，有 email 、openid、userid
    member_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户类型下的值


@attr.s
class TransferDriveMemberPermissionResp(object):
    is_success: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 请求是否成功
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文档类型 "doc" or "sheet" or "file"
    token: str = attr.ib(default="", metadata={"req_type": "json"})  # 文档的 token
    owner: TransferDriveMemberPermissionRespOwner = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文档当前所有者


def _gen_transfer_drive_member_permission_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=TransferDriveMemberPermissionResp,
        scope="Drive",
        api="TransferDriveMemberPermission",
        method="POST",
        url="https://open.feishu.cn/open-apis/drive/permission/member/transfer",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateTaskReqOriginHref(object):
    url: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 具体链接地址, 示例值："https://support.feishu.com/internal/foo-bar", 长度范围：`0` ～ `1024` 字符
    title: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 链接对应的标题, 示例值："反馈一个问题，需要协助排查", 长度范围：`0` ～ `512` 字符


@attr.s
class CreateTaskReqOrigin(object):
    platform_i18n_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 任务导入来源的名称，用于在任务中心详情页展示。请提供一个字典，多种语言名称映射。支持的各地区语言名：it_it, th_th, ko_kr, es_es, ja_jp, zh_cn, id_id, zh_hk, pt_br, de_de, fr_fr, zh_tw, ru_ru, en_us, hi_in, vi_vn, 示例值：""{\"zh_cn\": \"IT 工作台\", \"en_us\": \"IT Workspace\"}"", 长度范围：`0` ～ `1024` 字符
    href: CreateTaskReqOriginHref = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 任务关联的来源平台详情页链接


@attr.s
class CreateTaskReqDue(object):
    time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 截止时间的时间戳（单位为秒）, 示例值："1623124318"
    timezone: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 截止时间对应的时区，完整的时区名称列表可参考：https://docs.aws.amazon.com/zh_cn/redshift/latest/dg/time-zone-names.html, 示例值："Asia/Shanghai", 默认值: `Asia/Shanghai`
    is_all_day: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 标记任务是否为全天任务（全天任务的截止时间为当天 UTC 时间的 0 点）, 示例值：false, 默认值: `false`


@attr.s
class CreateTaskReqUserIDType(object):
    pass


@attr.s
class CreateTaskReq(object):
    user_id_type: CreateTaskReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`,, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    summary: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 任务标题。创建任务时，如果没有标题填充，飞书服务器会将其视为无主题的任务, 示例值："每天喝八杯水，保持身心愉悦", 长度范围：`1` ～ `256` 字符
    description: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 任务备注, 示例值："多吃水果，多运动，健康生活，快乐工作。", 长度范围：`0` ～ `65536` 字符
    extra: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 接入方可以自定义的附属信息二进制格式，采用 base64 编码，解析方式由接入方自己决定, 示例值："dGVzdA==", 长度范围：`0` ～ `65536` 字符
    due: CreateTaskReqDue = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 任务的截止时间设置
    origin: CreateTaskReqOrigin = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 任务关联的第三方平台来源信息


@attr.s
class CreateTaskRespTaskOriginHref(object):
    url: str = attr.ib(default="", metadata={"req_type": "json"})  # 具体链接地址
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 链接对应的标题


@attr.s
class CreateTaskRespTaskOrigin(object):
    platform_i18n_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 任务导入来源的名称，用于在任务中心详情页展示。请提供一个字典，多种语言名称映射。支持的各地区语言名：it_it, th_th, ko_kr, es_es, ja_jp, zh_cn, id_id, zh_hk, pt_br, de_de, fr_fr, zh_tw, ru_ru, en_us, hi_in, vi_vn
    href: CreateTaskRespTaskOriginHref = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 任务关联的来源平台详情页链接


@attr.s
class CreateTaskRespTaskDue(object):
    time: str = attr.ib(default="", metadata={"req_type": "json"})  # 截止时间的时间戳（单位为秒）
    timezone: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 截止时间对应的时区，完整的时区名称列表可参考：https://docs.aws.amazon.com/zh_cn/redshift/latest/dg/time-zone-names.html
    is_all_day: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 标记任务是否为全天任务（全天任务的截止时间为当天 UTC 时间的 0 点）


@attr.s
class CreateTaskRespTask(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 任务 ID，由飞书任务服务器发号
    summary: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 任务标题。创建任务时，如果没有标题填充，飞书服务器会将其视为无主题的任务
    description: str = attr.ib(default="", metadata={"req_type": "json"})  # 任务备注
    complete_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 任务的完成时间戳（单位为秒），如果完成时间为 0，则表示任务尚未完成
    creator_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 任务的创建者 ID。在创建任务时无需填充该字段
    extra: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 接入方可以自定义的附属信息二进制格式，采用 base64 编码，解析方式由接入方自己决定
    create_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 任务的创建时间戳（单位为秒）
    update_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 任务的更新时间戳（单位为秒）
    due: CreateTaskRespTaskDue = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 任务的截止时间设置
    origin: CreateTaskRespTaskOrigin = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 任务关联的第三方平台来源信息


@attr.s
class CreateTaskResp(object):
    task: CreateTaskRespTask = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 返回创建好的任务


def _gen_create_task_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateTaskResp,
        scope="Task",
        api="CreateTask",
        method="POST",
        url="https://open.feishu.cn/open-apis/task/v1/tasks",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteMeetingRoomRoomReq(object):
    room_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 要删除的会议室ID


@attr.s
class DeleteMeetingRoomRoomResp(object):
    pass


def _gen_delete_meeting_room_room_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteMeetingRoomRoomResp,
        scope="MeetingRoom",
        api="DeleteMeetingRoomRoom",
        method="POST",
        url="https://open.feishu.cn/open-apis/meeting_room/room/delete",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetDriveImportTaskReq(object):
    ticket: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 导入任务ID, 示例值："6990281865xxxxxxxx7843"


@attr.s
class GetDriveImportTaskRespResult(object):
    ticket: str = attr.ib(default="", metadata={"req_type": "json"})  # 任务ID
    type: str = attr.ib(default="", metadata={"req_type": "json"})  # 导入目标云文档格式
    job_status: int = attr.ib(default=0, metadata={"req_type": "json"})  # 任务状态
    job_error_msg: str = attr.ib(default="", metadata={"req_type": "json"})  # 任务失败原因
    token: str = attr.ib(default="", metadata={"req_type": "json"})  # 导入云文档Token
    url: str = attr.ib(default="", metadata={"req_type": "json"})  # 导入云文档URL
    extra: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 任务成功后的提示信息


@attr.s
class GetDriveImportTaskResp(object):
    result: GetDriveImportTaskRespResult = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 导入结果


def _gen_get_drive_import_task_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetDriveImportTaskResp,
        scope="Drive",
        api="GetDriveImportTask",
        method="GET",
        url="https://open.feishu.cn/open-apis/drive/v1/import_tasks/:ticket",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class StartVCMeetingRecordingReq(object):
    meeting_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 会议ID（视频会议的唯一标识，视频会议开始后才会产生）, 示例值："6911188411932033028"
    timezone: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 录制文件时间显示使用的时区[-12,12], 示例值：8


@attr.s
class StartVCMeetingRecordingResp(object):
    pass


def _gen_start_vc_meeting_recording_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=StartVCMeetingRecordingResp,
        scope="VC",
        api="StartVCMeetingRecording",
        method="PATCH",
        url="https://open.feishu.cn/open-apis/vc/v1/meetings/:meeting_id/recording/start",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHelpdeskAgentEmailReq(object):
    pass


@attr.s
class GetHelpdeskAgentEmailResp(object):
    agents: str = attr.ib(default="", metadata={"req_type": "json"})  # agent emails


def _gen_get_helpdesk_agent_email_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHelpdeskAgentEmailResp,
        scope="Helpdesk",
        api="GetHelpdeskAgentEmail",
        method="GET",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/agent_emails",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateSheetFilterReqCondition(object):
    filter_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 筛选类型, 示例值："number"
    compare_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 比较类型, 示例值："less"
    expected: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 筛选参数, 示例值：6


@attr.s
class UpdateSheetFilterReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 表格 token, 示例值："shtcnmBA\*****yGehy8"
    sheet_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 子表 id, 示例值："0b\**12"
    col: str = attr.ib(default="", metadata={"req_type": "json"})  # 更新筛选条件的列, 示例值："E"
    condition: UpdateSheetFilterReqCondition = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 筛选条件


@attr.s
class UpdateSheetFilterResp(object):
    pass


def _gen_update_sheet_filter_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateSheetFilterResp,
        scope="Drive",
        api="UpdateSheetFilter",
        method="PUT",
        url="https://open.feishu.cn/open-apis/sheets/v3/spreadsheets/:spreadsheet_token/sheets/:sheet_id/filter",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetACSUserFaceReqUserIDType(object):
    pass


@attr.s
class GetACSUserFaceReq(object):
    is_cropped: bool = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 裁剪图, 示例值：true
    user_id_type: GetACSUserFaceReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`,, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    user_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 用户 ID, 示例值："ou_7dab8a3d3cdcc9da365777c7ad535d62"


@attr.s
class GetACSUserFaceRespFile(object):
    pass


@attr.s
class GetACSUserFaceResp(object):
    file: typing.Union[str, bytes, io.BytesIO] = attr.ib(
        default=None, metadata={"req_type": "json"}
    )


@attr.s
class GetACSUserFaceResp(object):
    is_file: bool = attr.ib(factory=lambda: bool(), metadata={"req_type": "json"})
    code: int = attr.ib(default=0, metadata={"req_type": "json"})
    msg: str = attr.ib(default="", metadata={"req_type": "json"})
    data: GetACSUserFaceResp = attr.ib(default=None, metadata={"req_type": "json"})


def _gen_get_acs_user_face_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetACSUserFaceResp,
        scope="ACS",
        api="GetACSUserFace",
        method="GET",
        url="https://open.feishu.cn/open-apis/acs/v1/users/:user_id/face",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateHelpdeskCategoryReq(object):
    id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # category id, 示例值："6948728206392295444"
    name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 名称, 示例值："创建团队和邀请成员"
    parent_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 父知识库分类ID, 示例值："0"


@attr.s
class UpdateHelpdeskCategoryResp(object):
    pass


def _gen_update_helpdesk_category_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateHelpdeskCategoryResp,
        scope="Helpdesk",
        api="UpdateHelpdeskCategory",
        method="PATCH",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/categories/:id",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_bitable_view_list import (
    GetBitableViewListReq,
    GetBitableViewListResp,
    _gen_get_bitable_view_list_req,
)
from pylark.api_service_bitable_view_create import (
    CreateBitableViewReq,
    CreateBitableViewResp,
    _gen_create_bitable_view_req,
)
from pylark.api_service_bitable_view_delete import (
    DeleteBitableViewReq,
    DeleteBitableViewResp,
    _gen_delete_bitable_view_req,
)
from pylark.api_service_bitable_record_list import (
    GetBitableRecordListReq,
    GetBitableRecordListResp,
    _gen_get_bitable_record_list_req,
)
from pylark.api_service_bitable_record_get import (
    GetBitableRecordReq,
    GetBitableRecordResp,
    _gen_get_bitable_record_req,
)
from pylark.api_service_bitable_record_create import (
    CreateBitableRecordReq,
    CreateBitableRecordResp,
    _gen_create_bitable_record_req,
)
from pylark.api_service_bitable_record_batch_create import (
    BatchCreateBitableRecordReq,
    BatchCreateBitableRecordResp,
    _gen_batch_create_bitable_record_req,
)
from pylark.api_service_bitable_record_update import (
    UpdateBitableRecordReq,
    UpdateBitableRecordResp,
    _gen_update_bitable_record_req,
)
from pylark.api_service_bitable_record_batch_update import (
    BatchUpdateBitableRecordReq,
    BatchUpdateBitableRecordResp,
    _gen_batch_update_bitable_record_req,
)
from pylark.api_service_bitable_record_delete import (
    DeleteBitableRecordReq,
    DeleteBitableRecordResp,
    _gen_delete_bitable_record_req,
)
from pylark.api_service_bitable_record_batch_delete import (
    BatchDeleteBitableRecordReq,
    BatchDeleteBitableRecordResp,
    _gen_batch_delete_bitable_record_req,
)
from pylark.api_service_bitable_field_list import (
    GetBitableFieldListReq,
    GetBitableFieldListResp,
    _gen_get_bitable_field_list_req,
)
from pylark.api_service_bitable_field_create import (
    CreateBitableFieldReq,
    CreateBitableFieldResp,
    _gen_create_bitable_field_req,
)
from pylark.api_service_bitable_field_update import (
    UpdateBitableFieldReq,
    UpdateBitableFieldResp,
    _gen_update_bitable_field_req,
)
from pylark.api_service_bitable_field_delete import (
    DeleteBitableFieldReq,
    DeleteBitableFieldResp,
    _gen_delete_bitable_field_req,
)
from pylark.api_service_bitable_table_list import (
    GetBitableTableListReq,
    GetBitableTableListResp,
    _gen_get_bitable_table_list_req,
)
from pylark.api_service_bitable_table_create import (
    CreateBitableTableReq,
    CreateBitableTableResp,
    _gen_create_bitable_table_req,
)
from pylark.api_service_bitable_table_batch_create import (
    BatchCreateBitableTableReq,
    BatchCreateBitableTableResp,
    _gen_batch_create_bitable_table_req,
)
from pylark.api_service_bitable_table_delete import (
    DeleteBitableTableReq,
    DeleteBitableTableResp,
    _gen_delete_bitable_table_req,
)
from pylark.api_service_bitable_table_batch_delete import (
    BatchDeleteBitableTableReq,
    BatchDeleteBitableTableResp,
    _gen_batch_delete_bitable_table_req,
)
from pylark.api_service_bitable_meta_get import (
    GetBitableMetaReq,
    GetBitableMetaResp,
    _gen_get_bitable_meta_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkBitableService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def get_bitable_view_list(
        self, request: GetBitableViewListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetBitableViewListResp, Response]:
        return self.cli.raw_request(_gen_get_bitable_view_list_req(request, options))

    def create_bitable_view(
        self, request: CreateBitableViewReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateBitableViewResp, Response]:
        return self.cli.raw_request(_gen_create_bitable_view_req(request, options))

    def delete_bitable_view(
        self, request: DeleteBitableViewReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteBitableViewResp, Response]:
        return self.cli.raw_request(_gen_delete_bitable_view_req(request, options))

    def get_bitable_record_list(
        self, request: GetBitableRecordListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetBitableRecordListResp, Response]:
        return self.cli.raw_request(_gen_get_bitable_record_list_req(request, options))

    def get_bitable_record(
        self, request: GetBitableRecordReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetBitableRecordResp, Response]:
        return self.cli.raw_request(_gen_get_bitable_record_req(request, options))

    def create_bitable_record(
        self, request: CreateBitableRecordReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateBitableRecordResp, Response]:
        return self.cli.raw_request(_gen_create_bitable_record_req(request, options))

    def batch_create_bitable_record(
        self, request: BatchCreateBitableRecordReq, options: typing.List[str] = None
    ) -> typing.Tuple[BatchCreateBitableRecordResp, Response]:
        return self.cli.raw_request(
            _gen_batch_create_bitable_record_req(request, options)
        )

    def update_bitable_record(
        self, request: UpdateBitableRecordReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateBitableRecordResp, Response]:
        return self.cli.raw_request(_gen_update_bitable_record_req(request, options))

    def batch_update_bitable_record(
        self, request: BatchUpdateBitableRecordReq, options: typing.List[str] = None
    ) -> typing.Tuple[BatchUpdateBitableRecordResp, Response]:
        return self.cli.raw_request(
            _gen_batch_update_bitable_record_req(request, options)
        )

    def delete_bitable_record(
        self, request: DeleteBitableRecordReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteBitableRecordResp, Response]:
        return self.cli.raw_request(_gen_delete_bitable_record_req(request, options))

    def batch_delete_bitable_record(
        self, request: BatchDeleteBitableRecordReq, options: typing.List[str] = None
    ) -> typing.Tuple[BatchDeleteBitableRecordResp, Response]:
        return self.cli.raw_request(
            _gen_batch_delete_bitable_record_req(request, options)
        )

    def get_bitable_field_list(
        self, request: GetBitableFieldListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetBitableFieldListResp, Response]:
        return self.cli.raw_request(_gen_get_bitable_field_list_req(request, options))

    def create_bitable_field(
        self, request: CreateBitableFieldReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateBitableFieldResp, Response]:
        return self.cli.raw_request(_gen_create_bitable_field_req(request, options))

    def update_bitable_field(
        self, request: UpdateBitableFieldReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateBitableFieldResp, Response]:
        return self.cli.raw_request(_gen_update_bitable_field_req(request, options))

    def delete_bitable_field(
        self, request: DeleteBitableFieldReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteBitableFieldResp, Response]:
        return self.cli.raw_request(_gen_delete_bitable_field_req(request, options))

    def get_bitable_table_list(
        self, request: GetBitableTableListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetBitableTableListResp, Response]:
        return self.cli.raw_request(_gen_get_bitable_table_list_req(request, options))

    def create_bitable_table(
        self, request: CreateBitableTableReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateBitableTableResp, Response]:
        return self.cli.raw_request(_gen_create_bitable_table_req(request, options))

    def batch_create_bitable_table(
        self, request: BatchCreateBitableTableReq, options: typing.List[str] = None
    ) -> typing.Tuple[BatchCreateBitableTableResp, Response]:
        return self.cli.raw_request(
            _gen_batch_create_bitable_table_req(request, options)
        )

    def delete_bitable_table(
        self, request: DeleteBitableTableReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteBitableTableResp, Response]:
        return self.cli.raw_request(_gen_delete_bitable_table_req(request, options))

    def batch_delete_bitable_table(
        self, request: BatchDeleteBitableTableReq, options: typing.List[str] = None
    ) -> typing.Tuple[BatchDeleteBitableTableResp, Response]:
        return self.cli.raw_request(
            _gen_batch_delete_bitable_table_req(request, options)
        )

    def get_bitable_meta(
        self, request: GetBitableMetaReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetBitableMetaResp, Response]:
        return self.cli.raw_request(_gen_get_bitable_meta_req(request, options))



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateMeetingRoomBuildingReq(object):
    building_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 要更新的建筑ID
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 建筑名称
    floors: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 楼层列表
    country_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 国家/地区ID
    district_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 城市ID
    custom_building_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户自定义建筑ID


@attr.s
class UpdateMeetingRoomBuildingResp(object):
    pass


def _gen_update_meeting_room_building_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateMeetingRoomBuildingResp,
        scope="MeetingRoom",
        api="UpdateMeetingRoomBuilding",
        method="POST",
        url="https://open.feishu.cn/open-apis/meeting_room/building/update",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateAttendanceUserApprovalReqUserApprovalTrip(object):
    start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 开始时间，时间格式为 yyyy-MM-dd HH:mm:ss
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 结束时间，时间格式为 yyyy-MM-dd HH:mm:ss
    reason: str = attr.ib(default="", metadata={"req_type": "json"})  # 出差理由
    approve_pass_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批通过时间，时间格式为 yyyy-MM-dd HH:mm:ss
    approve_apply_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批申请时间，时间格式为 yyyy-MM-dd HH:mm:ss


@attr.s
class CreateAttendanceUserApprovalReqUserApprovalOvertimeWorkDuration(object):
    pass


@attr.s
class CreateAttendanceUserApprovalReqUserApprovalOvertimeWork(object):
    duration: float = attr.ib(default=None, metadata={"req_type": "json"})  # 加班时长
    unit: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 加班时长单位，可用值：【1（天），2（小时）】
    category: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 加班日期类型，可用值：【1（工作日），2（休息日），3（节假日）】
    type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 加班规则类型，可用值：【0（不关联加班规则），1（调休），2（加班费）】
    start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 开始时间，时间格式为 yyyy-MM-dd HH:mm:ss
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 结束时间，时间格式为 yyyy-MM-dd HH:mm:ss


@attr.s
class CreateAttendanceUserApprovalReqUserApprovalLeaveI18nNames(object):
    ch: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文描述
    en: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文描述
    ja: str = attr.ib(default="", metadata={"req_type": "json"})  # 日文描述


@attr.s
class CreateAttendanceUserApprovalReqUserApprovalLeave(object):
    uniq_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 假期类型唯一 ID，代表一种假期类型，长度小于 14
    unit: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 假期时长单位，可用值：【1（天），2（小时），3（半天），4（半小时）】
    interval: int = attr.ib(default=0, metadata={"req_type": "json"})  # 假期时长（单位秒）
    start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 开始时间，时间格式为 yyyy-MM-dd HH:mm:ss
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 结束时间，时间格式为 yyyy-MM-dd HH:mm:ss
    i18n_names: CreateAttendanceUserApprovalReqUserApprovalLeaveI18nNames = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 假期多语言展示，格式为 map，key 为["ch"、"en"、"ja"]，其中 ch 代表中文，en 代表英文、ja 代表日文
    default_locale: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 默认语言类型，由于飞书客户端支持中、英、日三种语言，当用户切换语言时，如果假期名称没有所对应语言的名称，则会使用默认语言的名称，可用值：【ch（中文），en（英文），ja（日文）】
    reason: str = attr.ib(default="", metadata={"req_type": "json"})  # 请假理由，必选字段


@attr.s
class CreateAttendanceUserApprovalReqUserApprovalOutI18nNamesJa(object):
    pass


@attr.s
class CreateAttendanceUserApprovalReqUserApprovalOutI18nNames(object):
    ch: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文描述
    en: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文描述
    ja: CreateAttendanceUserApprovalReqUserApprovalOutI18nNamesJa = attr.ib(
        factory=lambda: CreateAttendanceUserApprovalReqUserApprovalOutI18nNamesJa(),
        metadata={"req_type": "json"},
    )  # 日文描述


@attr.s
class CreateAttendanceUserApprovalReqUserApprovalOut(object):
    uniq_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 外出类型唯一 ID，代表一种外出类型，长度小于 14
    unit: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 外出时长单位，可用值：【1（天），2（小时），3（半天），4（半小时）】
    interval: int = attr.ib(default=0, metadata={"req_type": "json"})  # 假期时长（单位秒）
    start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 开始时间，时间格式为 yyyy-MM-dd HH:mm:ss
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 结束时间，时间格式为 yyyy-MM-dd HH:mm:ss
    i18n_names: CreateAttendanceUserApprovalReqUserApprovalOutI18nNames = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 外出多语言展示，格式为 map，key 为["ch"、"en"、"ja"]，其中 ch 代表中文，en 代表英文、ja 代表日文
    default_locale: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 默认语言类型，由于飞书客户端支持中、英、日三种语言，当用户切换语言时，如果外出名称没有所对应语言的名称，则会使用默认语言的名称
    reason: str = attr.ib(default="", metadata={"req_type": "json"})  # 外出理由


@attr.s
class CreateAttendanceUserApprovalReqUserApproval(object):
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批用户
    date: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批作用时间
    outs: typing.List[CreateAttendanceUserApprovalReqUserApprovalOut] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 外出信息
    leaves: typing.List[CreateAttendanceUserApprovalReqUserApprovalLeave] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 请假信息
    overtime_works: typing.List[
        CreateAttendanceUserApprovalReqUserApprovalOvertimeWork
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 加班信息
    trips: typing.List[CreateAttendanceUserApprovalReqUserApprovalTrip] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 出差信息


@attr.s
class CreateAttendanceUserApprovalReqEmployeeType(object):
    pass


@attr.s
class CreateAttendanceUserApprovalReq(object):
    employee_type: CreateAttendanceUserApprovalReqEmployeeType = attr.ib(
        factory=lambda: CreateAttendanceUserApprovalReqEmployeeType(),
        metadata={"req_type": "query"},
    )  # 请求体中的 user_id 的员工工号类型，必选字段，可用值：【employee_id（员工employeeId），employee_no（员工工号）】，示例值："employee_id"
    user_approval: CreateAttendanceUserApprovalReqUserApproval = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 审批信息


@attr.s
class CreateAttendanceUserApprovalRespUserApprovalTrip(object):
    approval_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例ID
    start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 开始时间，时间格式为 yyyy-MM-dd HH:mm:ss
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 结束时间，时间格式为 yyyy-MM-dd HH:mm:ss
    reason: str = attr.ib(default="", metadata={"req_type": "json"})  # 出差理由
    approve_pass_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批通过时间，时间格式为 yyyy-MM-dd HH:mm:ss
    approve_apply_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批申请时间，时间格式为 yyyy-MM-dd HH:mm:ss


@attr.s
class CreateAttendanceUserApprovalRespUserApprovalOvertimeWorkDuration(object):
    pass


@attr.s
class CreateAttendanceUserApprovalRespUserApprovalOvertimeWork(object):
    approval_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例ID
    duration: float = attr.ib(default=None, metadata={"req_type": "json"})  # 加班时长
    unit: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 加班时长单位，可用值：【1（天），2（小时）】
    category: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 加班日期类型，可用值：【1（工作日），2（休息日），3（节假日）】
    type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 加班规则类型，可用值：【0（不关联加班规则），1（调休），2（加班费），3（关联加班规则，没有调休或加班费）】
    start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 开始时间，时间格式为 yyyy-MM-dd HH:mm:ss
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 结束时间，时间格式为 yyyy-MM-dd HH:mm:ss


@attr.s
class CreateAttendanceUserApprovalRespUserApprovalLeaveI18nNames(object):
    ch: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文描述
    en: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文描述
    ja: str = attr.ib(default="", metadata={"req_type": "json"})  # 日文描述


@attr.s
class CreateAttendanceUserApprovalRespUserApprovalLeave(object):
    approval_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例ID
    uniq_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 假期类型唯一 ID，代表一种假期类型，长度小于 14
    unit: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 假期时长单位，可用值：【1（天），2（小时），3（半天），4（半小时）】
    interval: int = attr.ib(default=0, metadata={"req_type": "json"})  # 假期时长（单位秒）
    start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 开始时间，时间格式为 yyyy-MM-dd HH:mm:ss
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 结束时间，时间格式为 yyyy-MM-dd HH:mm:ss
    i18n_names: CreateAttendanceUserApprovalRespUserApprovalLeaveI18nNames = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 假期多语言展示，格式为 map，key 为["ch"、"en"、"ja"]，其中 ch 代表中文，en 代表英文、ja 代表日文
    default_locale: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 默认语言类型，由于飞书客户端支持中、英、日三种语言，当用户切换语言时，如果假期名称没有所对应语言的名称，则会使用默认语言的名称，可用值：【ch（中文），en（英文），ja（日文）】
    reason: str = attr.ib(default="", metadata={"req_type": "json"})  # 请假理由
    approve_pass_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批通过时间，时间格式为 yyyy-MM-dd HH:mm:ss
    approve_apply_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批申请时间，时间格式为 yyyy-MM-dd HH:mm:ss


@attr.s
class CreateAttendanceUserApprovalRespUserApprovalOutI18nNames(object):
    ch: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文描述
    en: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文描述
    ja: str = attr.ib(default="", metadata={"req_type": "json"})  # 日文描述


@attr.s
class CreateAttendanceUserApprovalRespUserApprovalOut(object):
    approval_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例ID
    uniq_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 外出类型唯一 ID，代表一种外出类型，长度小于 14
    unit: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 外出时长单位，可用值：【1（天），2（小时），3（半天），4（半小时）】
    interval: int = attr.ib(default=0, metadata={"req_type": "json"})  # 假期时长（单位秒）
    start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 开始时间，时间格式为 yyyy-MM-dd HH:mm:ss
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 结束时间，时间格式为 yyyy-MM-dd HH:mm:ss
    i18n_names: CreateAttendanceUserApprovalRespUserApprovalOutI18nNames = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 外出多语言展示，格式为 map，key 为["ch"、"en"、"ja"]，其中 ch 代表中文，en 代表英文、ja 代表日文
    default_locale: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 默认语言类型，由于飞书客户端支持中、英、日三种语言，当用户切换语言时，如果外出名称没有所对应语言的名称，则会使用默认语言的名称
    reason: str = attr.ib(default="", metadata={"req_type": "json"})  # 外出理由
    approve_pass_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批通过时间
    approve_apply_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批申请时间


@attr.s
class CreateAttendanceUserApprovalRespUserApproval(object):
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批用户 ID
    date: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批作用时间
    outs: typing.List[CreateAttendanceUserApprovalRespUserApprovalOut] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 外出信息
    leaves: typing.List[CreateAttendanceUserApprovalRespUserApprovalLeave] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 请假信息
    overtime_works: typing.List[
        CreateAttendanceUserApprovalRespUserApprovalOvertimeWork
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 加班信息
    trips: typing.List[CreateAttendanceUserApprovalRespUserApprovalTrip] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 出差信息


@attr.s
class CreateAttendanceUserApprovalResp(object):
    user_approvals: typing.List[CreateAttendanceUserApprovalRespUserApproval] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 审批结果列表


def _gen_create_attendance_user_approval_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateAttendanceUserApprovalResp,
        scope="Attendance",
        api="CreateAttendanceUserApproval",
        method="POST",
        url="https://open.feishu.cn/open-apis/attendance/v1/user_approvals",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateDriveFolderReq(object):
    folder_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 文件夹的 token，获取方式见 [概述](https://open.feishu.cn/document/ukTMukTMukTM/uUDN04SN0QjL1QDN/files/guide/introduction)
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件夹标题


@attr.s
class CreateDriveFolderResp(object):
    url: str = attr.ib(default="", metadata={"req_type": "json"})  # 新创建文件夹的 url
    revision: int = attr.ib(default=0, metadata={"req_type": "json"})  # 新创建文件夹的版本号
    token: str = attr.ib(default="", metadata={"req_type": "json"})  # 新创建文件夹的 token


def _gen_create_drive_folder_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateDriveFolderResp,
        scope="Drive",
        api="CreateDriveFolder",
        method="POST",
        url="https://open.feishu.cn/open-apis/drive/explorer/v2/folder/:folderToken",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UploadFileReqFile(object):
    pass


@attr.s
class UploadFileReqFileType(object):
    pass


@attr.s
class UploadFileReq(object):
    file_type: UploadFileReqFileType = attr.ib(
        factory=lambda: UploadFileReqFileType(), metadata={"req_type": "json"}
    )  # 文件类型, 示例值："mp4", 可选值有: `opus`：上传opus音频文件；,其他格式的音频文件，请转为opus格式后上传，转换方式可参考：ffmpeg -i  SourceFile.mp3 -acodec libopus -ac 1 -ar 16000 TargetFile.opus, `mp4`：上传mp4视频文件, `pdf`：上传pdf格式文件, `doc`：上传doc格式文件, `xls`：上传xls格式文件, `ppt`：上传ppt格式文件, `stream`：上传stream格式文件
    file_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 带后缀的文件名, 示例值："测试视频.mp4"
    duration: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 文件的时长(视频，音频),单位:毫秒, 示例值：3000
    file: typing.Union[str, bytes, io.BytesIO] = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文件内容, 示例值：二进制文件


@attr.s
class UploadFileResp(object):
    file_key: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件的key


def _gen_upload_file_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UploadFileResp,
        scope="File",
        api="UploadFile",
        method="POST",
        url="https://open.feishu.cn/open-apis/im/v1/files",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        is_file=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHelpdeskTicketListReqCustomizedFields(object):
    pass


@attr.s
class GetHelpdeskTicketListReq(object):
    ticket_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 搜索条件：工单ID, 示例值："123456"
    agent_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 搜索条件: 客服id, 示例值："ou_b5de90429xxx"
    closed_by_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 搜索条件: 关单客服id, 示例值："ou_b5de90429xxx"
    type: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 搜索条件: 工单类型 1:bot 2:人工, 示例值：1
    channel: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 搜索条件: 工单渠道, 示例值：0
    solved: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 搜索条件: 工单是否解决 1:没解决 2:已解决, 示例值：1
    score: int = attr.ib(default=0, metadata={"req_type": "query"})  # 搜索条件: 工单评分, 示例值：1
    status_list: typing.List[int] = attr.ib(
        factory=lambda: [], metadata={"req_type": "query"}
    )  # 搜索条件: 工单状态列表
    guest_name: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 搜索条件: 用户名称, 示例值："abc"
    guest_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 搜索条件: 用户id, 示例值："ou_b5de90429xxx"
    customized_fields: typing.List[GetHelpdeskTicketListReqCustomizedFields] = attr.ib(
        factory=lambda: [], metadata={"req_type": "query"}
    )  # 搜索条件: 自定义字段列表
    tags: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "query"}
    )  # 搜索条件: 用户标签列表
    page: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 页数, 从1开始, 默认为1, 示例值：1
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 当前页大小，最大为200, 默认为20。分页查询最多累计返回一万条数据，超过一万条请更改查询条件，推荐通过时间查询。, 示例值：20
    create_time_start: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 搜索条件: 工单创建起始时间 ms (也需要填上create_time_end)，相当于>=create_time_start, 示例值：1616920429000
    create_time_end: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 搜索条件: 工单创建结束时间 ms (也需要填上create_time_start)，相当于<=create_time_end, 示例值：1616920429000
    update_time_start: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 搜索条件: 工单修改起始时间 ms (也需要填上update_time_end), 示例值：1616920429000
    update_time_end: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 搜索条件: 工单修改结束时间 ms(也需要填上update_time_start), 示例值：1616920429000


@attr.s
class GetHelpdeskTicketListRespTicketCustomizedField(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 自定义字段ID
    value: str = attr.ib(default="", metadata={"req_type": "json"})  # 自定义字段值
    key_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 键名
    display_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 展示名称
    position: int = attr.ib(default=0, metadata={"req_type": "json"})  # 展示位置
    required: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否必填
    editable: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否可修改


@attr.s
class GetHelpdeskTicketListRespTicketCollaborator(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像url
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户名
    email: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户邮箱


@attr.s
class GetHelpdeskTicketListRespTicketClosedBy(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像url
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户名
    email: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户邮箱


@attr.s
class GetHelpdeskTicketListRespTicketAgent(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像url
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户名
    email: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户邮箱


@attr.s
class GetHelpdeskTicketListRespTicketGuest(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像url
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户名
    email: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户邮箱


@attr.s
class GetHelpdeskTicketListRespTicket(object):
    ticket_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 工单ID
    helpdesk_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 服务台ID
    guest: GetHelpdeskTicketListRespTicketGuest = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 工单创建用户
    stage: int = attr.ib(default=0, metadata={"req_type": "json"})  # 工单阶段，1：bot，2：人工
    status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 工单状态，1：已创建 2: 处理中 3: 排队中 4：待定 5：待用户响应 50: 被机器人关闭 51: 被人工关闭
    score: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 工单评分，1：不满意，2:一般，3:满意
    created_at: int = attr.ib(default=0, metadata={"req_type": "json"})  # 工单创建时间
    updated_at: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 工单更新时间，没有值时为-1
    closed_at: int = attr.ib(default=0, metadata={"req_type": "json"})  # 工单结束时间
    agents: typing.List[GetHelpdeskTicketListRespTicketAgent] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 工单客服
    channel: int = attr.ib(default=0, metadata={"req_type": "json"})  # 工单渠道
    solve: int = attr.ib(default=0, metadata={"req_type": "json"})  # 工单是否解决 1:没解决 2:已解决
    closed_by: GetHelpdeskTicketListRespTicketClosedBy = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 关单用户ID
    collaborators: typing.List[GetHelpdeskTicketListRespTicketCollaborator] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 工单协作者
    customized_fields: typing.List[
        GetHelpdeskTicketListRespTicketCustomizedField
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 自定义字段列表，没有值时不设置


@attr.s
class GetHelpdeskTicketListResp(object):
    total: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 工单总数 (单次请求最大为10000条)
    tickets: typing.List[GetHelpdeskTicketListRespTicket] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 工单


def _gen_get_helpdesk_ticket_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHelpdeskTicketListResp,
        scope="Helpdesk",
        api="GetHelpdeskTicketList",
        method="GET",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/tickets",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetSearchDataSourceReq(object):
    data_source_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 数据源的唯一标识, 示例值："service_ticket"


@attr.s
class GetSearchDataSourceRespDataSource(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 数据源的唯一标识
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # data_source的展示名称
    state: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 数据源状态，0-未上线，1-已上线, 可选值有: `0`：未上线, `1`：已上线
    description: str = attr.ib(default="", metadata={"req_type": "json"})  # 对于数据源的描述
    create_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 创建时间，使用Unix时间戳，单位为“秒”
    update_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 更新时间，使用Unix时间戳，单位为“秒”
    is_exceed_quota: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否超限


@attr.s
class GetSearchDataSourceResp(object):
    data_source: GetSearchDataSourceRespDataSource = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 数据源实例


def _gen_get_search_data_source_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetSearchDataSourceResp,
        scope="Search",
        api="GetSearchDataSource",
        method="GET",
        url="https://open.feishu.cn/open-apis/search/v2/data_sources/:data_source_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetFaceVerifyAuthResultReq(object):
    req_order_no: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 人脸识别单次唯一标识，由`tt.startFaceVerify`接口返回
    open_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 用户应用标识, 与employee_id二选其一
    employee_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 用户租户标识, 与open_id二选其一


@attr.s
class GetFaceVerifyAuthResultResp(object):
    auth_state: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 认证结果, 0: 认证中, 1: 认证成功, -1: 认证失败
    auth_timpstamp: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 认证时间，unix 时间戳


def _gen_get_face_verify_auth_result_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetFaceVerifyAuthResultResp,
        scope="HumanAuth",
        api="GetFaceVerifyAuthResult",
        method="GET",
        url="https://open.feishu.cn/open-apis/face_verify/v1/query_auth_result",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )
